@@ -6,7 +6,7 @@ use Carp ();
 use NEXT;
 use Net::LDAP;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 our $AUTOLOAD;
 
 =head1 NAME
@@ -15,39 +15,43 @@ Catalyst::Model::LDAP - LDAP model class for Catalyst
 
 =head1 SYNOPSIS
 
-  # Use the Catalyst helper
-  script/myapp_create.pl model Person LDAP ldap.ufl.edu ou=People,dc=ufl,dc=edu
+    # Use the Catalyst helper
+    script/myapp_create.pl model Person LDAP ldap.ufl.edu ou=People,dc=ufl,dc=edu
 
-  # lib/MyApp/Model/Person.pm
-  package MyApp::Model::Person;
+    # lib/MyApp/Model/Person.pm
+    package MyApp::Model::Person;
 
-  use base 'Catalyst::Model::LDAP';
+    use base 'Catalyst::Model::LDAP';
 
-  __PACKAGE__->config(
-      host         => 'ldap.ufl.edu',
-      base         => 'ou=People,dc=ufl,dc=edu',
-      dn           => '',
-      password     => '',
-      options      => {},  # Options passed to all Net::LDAP methods
-                           # (e.g. SASL for bind or sizelimit for
-                           # search)
-  );
+    __PACKAGE__->config(
+        host         => 'ldap.ufl.edu',
+        base         => 'ou=People,dc=ufl,dc=edu',
+        dn           => '',
+        password     => '',
+        options      => {},  # Options passed to all Net::LDAP methods
+                             # (e.g. SASL for bind or sizelimit for
+                             # search)
+    );
 
-  1;
+    1;
 
-  # In your controller
-  my $mesg = $c->model('Person')->search('(sn=TEST)');
-  my @entries = $mesg->entries;
-  print $entries[0]->get_value('sn');
+    # In your controller
+    my $mesg = $c->model('Person')->search('(cn=Lou Rhodes)');
+    my @entries = $mesg->entries;
+    print $entries[0]->get_value('sn');
 
 =head1 DESCRIPTION
 
-This is the L<Net::LDAP> model class for Catalyst. It is nothing more
+This is the L<Net::LDAP> model class for Catalyst.  It is nothing more
 than a simple wrapper for L<Net::LDAP>.
 
-This class simplifies LDAP searches by letting you configure a base
-DN. Other L<Net::LDAP> methods are supported via Perl's AUTOLOAD
-mechanism.
+This class simplifies LDAP access by letting you configure a common
+set of bind arguments and options.  It also lets you configure a base
+DN for searching.
+
+L<Net::LDAP> methods are supported via Perl's C<AUTOLOAD> mechanism.
+Please refer to the L<Net::LDAP> documentation for information on
+what's available.
 
 =head1 METHODS
 
@@ -58,9 +62,9 @@ Create a new Catalyst LDAP model component.
 =cut
 
 sub new {
-    my ($self, $c, $config) = @_;
+    my ($class, $c, $config) = @_;
 
-    $self = $self->NEXT::new($c, $config);
+    my $self = $class->NEXT::new($c, $config);
     $self->config($config);
 
     return $self;
@@ -68,7 +72,8 @@ sub new {
 
 =head2 _client
 
-Bind the client using the current configuration and return it.
+Bind the client using the current configuration and return it.  This
+method is automatically called when you use a L<Net::LDAP> method.
 
 =cut
 
@@ -98,7 +103,11 @@ sub _client {
 
 =head2 _execute
 
-Execute the specified LDAP command.
+Execute the specified LDAP command.  Call the appropriate L<Net::LDAP>
+methods directly instead of this method.  For example:
+
+    # In your controller
+    my $mesg = $c->model('Person')->search('(cn=Andy Barlow)');
 
 =cut
 
@@ -143,15 +152,12 @@ sub AUTOLOAD {
 
 Daniel Westermann-Clark E<lt>danieltwc@cpan.orgE<gt>
 
-Based on work started by E<lt>salih@ip-plus.netE<gt> on the Catalyst
-mailing list:
-
-L<http://lists.rawmode.org/pipermail/catalyst/2005-June/000712.html>
-
 =head1 ACKNOWLEDGEMENTS
 
 =over 4
 
+=item * Salih Gonullu, for initial work on Catalyst mailing list
+
 =item * Christopher H. Laco, for C<AUTOLOAD> idea
 
 =back
